==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway.md <==
# AmazonVpcInternetGateway


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')
```



| Illustration | AmazonVpcInternetGateway | AmazonVpcInternetGatewayCard | AmazonVpcInternetGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway.png) | ![illustration for AmazonVpcInternetGateway](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway.Local.png) | ![illustration for AmazonVpcInternetGatewayCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGatewayCard.Local.png) | ![illustration for AmazonVpcInternetGatewayGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGatewayGroup.Local.png) |




## AmazonVpcInternetGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGateway
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGateway('AmazonVpcInternetGateway', 'Amazon Vpc Internet Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGateway
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGateway('AmazonVpcInternetGateway', 'Amazon Vpc Internet Gateway', 'an optional tech label')
@enduml
```

## AmazonVpcInternetGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGatewayCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGatewayCard('AmazonVpcInternetGatewayCard', 'Amazon Vpc Internet Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGatewayCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGatewayCard('AmazonVpcInternetGatewayCard', 'Amazon Vpc Internet Gateway Card', 'an optional description')
@enduml
```

## AmazonVpcInternetGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGatewayGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGatewayGroup('AmazonVpcInternetGatewayGroup', 'Amazon Vpc Internet Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGatewayGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGatewayGroup('AmazonVpcInternetGatewayGroup', 'Amazon Vpc Internet Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway.md <==
# AmazonVpcInternetGateway


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')
```



| Illustration | AmazonVpcInternetGateway | AmazonVpcInternetGatewayCard | AmazonVpcInternetGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway.png) | ![illustration for AmazonVpcInternetGateway](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway.Local.png) | ![illustration for AmazonVpcInternetGatewayCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGatewayCard.Local.png) | ![illustration for AmazonVpcInternetGatewayGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGatewayGroup.Local.png) |




## AmazonVpcInternetGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGateway
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGateway('AmazonVpcInternetGateway', 'Amazon Vpc Internet Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGateway
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGateway('AmazonVpcInternetGateway', 'Amazon Vpc Internet Gateway', 'an optional tech label')
@enduml
```

## AmazonVpcInternetGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGatewayCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGatewayCard('AmazonVpcInternetGatewayCard', 'Amazon Vpc Internet Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGatewayCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGatewayCard('AmazonVpcInternetGatewayCard', 'Amazon Vpc Internet Gateway Card', 'an optional description')
@enduml
```

## AmazonVpcInternetGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGatewayGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGatewayGroup('AmazonVpcInternetGatewayGroup', 'Amazon Vpc Internet Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcInternetGatewayGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcInternetGateway')

' renders the element
AmazonVpcInternetGatewayGroup('AmazonVpcInternetGatewayGroup', 'Amazon Vpc Internet Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
